pub enum Error {
BufferTooShort(usize),
BufferUnaligned(usize),
Malformed(&'static str),
ImageNotFound(u64),
ExceptionDirectoryNotFound(Option<&'static str>),
RuntimeFunctionNotFound(Option<&'static str>, u32),
UnwindInfoNotFound(Option<&'static str>, u64, u32),
StackOffsetNotFound(Option<&'static str>),
StackTraceDumpFailed(Option<&'static str>),
}Expand description
The error type for stacktrace operations.
Variants
BufferTooShort(usize)
Error during parsing the PE
BufferUnaligned(usize)
Error thrown when buffer is not aligned
Malformed(&'static str)
Unexpected values during parsing the PE
ImageNotFound(u64)
Failed to locate a PE Image in memory
ExceptionDirectoryNotFound(Option<&'static str>)
Unable to locate the runtime function for the given rip(rva)
RuntimeFunctionNotFound(Option<&'static str>, u32)
Unable to locate the runtime function for the given rip(rva)
UnwindInfoNotFound(Option<&'static str>, u64, u32)
Failed to locate unwind info at the given image base
StackOffsetNotFound(Option<&'static str>)
Failed to calculate the stack offset
StackTraceDumpFailed(Option<&'static str>)
Failed to dump all the frames in the stack trace